@@ -4,9 +4,10 @@ from typing import List
 from logging import getLogger
 from sys import version_info
 
-from aiohttp import WSMessage, ClientWebSocketResponse
+from aiohttp import WSMessage, ClientWebSocketResponse, WSMsgType
+from aiohttp.http import WS_CLOSED_MESSAGE
 
-from .events import TitleUpdateEvent, PlayListUpdateEvent, EncodeEvent, EventType
+from .events import TitleUpdateEvent, PlayListUpdateEvent, EncodeEvent, EventType, TorrentUpdateEvent
 from ..http import HTTPCLient
 from ..listener import EventListener
 
@@ -61,6 +62,9 @@ class WebSocketClient:
 
             while not self._closed:
                 packet = await self._client.receive()
+                if self._client is None or packet in [WSMsgType.CLOSE, WS_CLOSED_MESSAGE]:
+                    await self.__connect()
+                    break
                 await self._process_packet(packet)
 
     async def _process_packet(self, packet: WSMessage):
@@ -82,7 +86,7 @@ class WebSocketClient:
 
         event_name = f"on_{type}"
         if type == EventType.TITLE_UPDATE:
-            self._dispatch_title_update_event(data)
+            self._dispatch_title_update_event(data["title_update"])
         elif type == EventType.PLAYLIST_UPDATE:
             event = PlayListUpdateEvent(**data[type])
             self._listener.dispatch(event_name, event)
@@ -90,9 +94,13 @@ class WebSocketClient:
             EventType.ENCODE_START,
             EventType.ENCODE_END,
             EventType.ENCODE_PROGRESS,
+            EventType.ENCODE_FINISH
         ]:
             event = EncodeEvent(**data[type])
             self._listener.dispatch(event_name, event)
+        elif type == EventType.TORRENT_UPDATE:
+            event = TorrentUpdateEvent(**data[type])
+            self._listener.dispatch(event_name, event)
         else:
             self._listener.dispatch(event_name, data)
             log.debug(f"Not documented event type {type} dispatched with data: {data}")
@@ -107,8 +115,8 @@ class WebSocketClient:
         :param data: Словарь с данными об ивенте
         :type data: dict
         """
-        event_model = TitleUpdateEvent(**data[type])
-        self._listener.dispatch(data["type"], event_model)
+        event_model = TitleUpdateEvent(**data)
+        self._listener.dispatch("on_title_update", event_model)
 
         title_data = data["title"]
         events = self._listener.events
